@@ -1,4 +1,4 @@
-try: 
+try:
     from .adaopt import AdaOpt
 except ImportError as e:
     print(f"Could not import some modules: {e}")
@@ -14,7 +14,11 @@ except ImportError as e:
     print(f"Could not import some modules: {e}")
 
 try:
-    from .lazybooster import LazyBoostingClassifier, LazyBoostingRegressor, LazyBoostingMTS
+    from .lazybooster import (
+        LazyBoostingClassifier,
+        LazyBoostingRegressor,
+        LazyBoostingMTS,
+    )
 except ImportError as e:
     print(f"Could not import some modules: {e}")
 
@@ -23,7 +27,7 @@ try:
 except ImportError as e:
     print(f"Could not import some modules: {e}")
 
-try:        
+try:
     from .datasets import download
 except ImportError as e:
     print(f"Could not import some modules: {e}")
@@ -33,7 +37,7 @@ try:
 except ImportError as e:
     print(f"Could not import some modules: {e}")
 
-try: 
+try:
     from .kernelridge import KRLSRegressor
 except ImportError as e:
     print(f"Could not import some modules: {e}")
@@ -53,8 +57,40 @@ try:
 except ImportError as e:
     print(f"Could not import some modules: {e}")
 
+try:
+    from .isotonicregression import IsotonicRegressor
+except ImportError as e:
+    print(f"Could not import some modules: {e}")
+
+try:
+    from .fpca import GenericFunctionalForecaster
+except ImportError as e:
+    print(f"Could not import some modules: {e}")
+
+try: 
+    from .generators import make_diverse_classification,\
+    HealthcareTimeSeriesGenerator,\
+    generate_synthetic_returns,\
+    plot_synthetic_returns
+except ImportError as e:
+    print(f"Could not import generators: {e}")
+
+try:
+    from .catencoder import RankTargetEncoder
+except ImportError as e:
+    print(f"Could not import RankTargetEncoder: {e}")
+
+try:
+    from .rollingoriginregression import RollingOriginForecaster
+except ImportError as e:
+    print(f"Could not import RollingOriginForecaster: {e}")
 # from .encoders import corrtarget_encoder
 
+try:
+    from .penalizedcv import penalized_cross_val_score
+except ImportError as e:
+    print(f"Could not import penalized_cross_val_score: {e}")
+
 __all__ = [
     "AdaOpt",
     "LSBoostClassifier",
@@ -65,11 +101,16 @@ __all__ = [
     "KRLSRegressor",
     "LassoRegressor",
     "LSBoostRegressor",
+    "LSTMRegressor",
     "RidgeRegressor",
     "LazyBoostingClassifier",
     "LazyBoostingMTS",
     "LazyBoostingRegressor",
     "MultiTaskRegressor",
+    "IsotonicRegressor",
+    "GenericFunctionalForecaster",
+    "RankTargetEncoder",
+    "RollingOriginForecaster",
     # Other imports
     # "corrtarget_encoder",
     "download",
@@ -77,5 +118,9 @@ __all__ = [
     "get_config",
     "set_config",
     "config_context",
+    "penalized_cross_val_score",
+    "make_diverse_classification",
+    "HealthcareTimeSeriesGenerator",
+    "generate_synthetic_returns",
+    "plot_synthetic_returns"
 ]
-
