@@ -83,10 +83,10 @@ class LSBoostClassifier(BaseEstimator, ClassifierMixin):
         weights_distr: str
             distribution of weights for constructing the model's hidden layer;
             currently 'uniform', 'gaussian'
-        
+
         hist: bool
             indicates whether histogram features are used or not (default is False)
-        
+
         bins: int or str
             number of bins for histogram features (same as numpy.histogram, default is 'auto')
 
@@ -402,14 +402,14 @@ class LSBoostClassifier(BaseEstimator, ClassifierMixin):
 
         if isinstance(X, pd.DataFrame):
             X = X.values
-        
+
         if self.hist == True:
             X, self.hist_bins_ = get_histo_features(X)
-        
+
         if isinstance(y, pd.Series):
             y = y.values.ravel()
         else:
-            y = y.ravel()
+            y = np.asarray(y).ravel()
 
         if self.degree is not None:
             assert isinstance(self.degree, int), "`degree` must be an integer"
@@ -566,8 +566,10 @@ class LSBoostClassifier(BaseEstimator, ClassifierMixin):
             )
 
         self.obj = boosterc.update_booster(
-            self.obj, np.asarray(X, order="C"), 
-            np.asarray(y, order="C").ravel(), eta
+            self.obj,
+            np.asarray(X, order="C"),
+            np.asarray(y, order="C").ravel(),
+            eta,
         )
 
         return self
@@ -630,10 +632,10 @@ class GenericBoostingClassifier(LSBoostClassifier):
         weights_distr: str
             distribution of weights for constructing the model's hidden layer;
             currently 'uniform', 'gaussian'
-        
+
         hist: bool
             indicates whether histogram features are used or not (default is False)
-        
+
         bins: int or str
             number of bins for histogram features (same as numpy.histogram, default is 'auto')
 
@@ -686,4 +688,4 @@ class GenericBoostingClassifier(LSBoostClassifier):
             degree=degree,
             weights_distr=weights_distr,
             base_model=self.base_model,
-        )
\ No newline at end of file
+        )
