@@ -1,3 +1,3 @@
 from .gethistofeatures import get_histo_features
 
-__all__ = ['get_histo_features']
\ No newline at end of file
+__all__ = ["get_histo_features"]
