@@ -1,4 +1,4 @@
 from .rowsubsampling import subsample
 
 
-__all__=[subsample]
\ No newline at end of file
+__all__ = ["subsample"]
